==> humhub-1.8.1.tar.gz: humhub-1.8.1/protected/humhub/modules/admin/messages/it/user.php <==
<?php
return array (
  '<strong>Information</strong>' => '<strong>Informazioni</strong>',
  '<strong>Profile</strong> Permissions' => '',
  '<strong>Settings</strong> and Configuration' => '<strong>Impostazioni</strong> e Configurazione',
  '<strong>User</strong> administration' => 'Amministrazione <strong>Utente</strong>',
  '<strong>Warning:</strong> All individual profile permission settings are reset to the default values!' => '',
  'Accept user: <strong>{displayName}</strong> ' => 'Accetta utente: <strong>{displayName}</strong>',
  'Account' => 'Account',
  'Account Request for \'{displayName}\' has been approved.' => 'La richiesta account per \'{displayName}\'  è stata approvata',
  'Account Request for \'{displayName}\' has been declined.' => 'La richiesta account per \'{displayName}\'  è stata rifiutata',
  'Actions' => 'Azioni',
  'Active users' => 'Utenti attivi',
  'Add Groups...' => 'Aggiungi Gruppi...',
  'Add a separate page for the group to the directory.' => '',
  'Add new category' => 'Aggiungi nuova categoria',
  'Add new field' => 'Aggiungi nuovo campo',
  'Add new group' => 'Aggiungi nuovo gruppo',
  'Add new members...' => 'Aggiungi nuovi membri...',
  'Add new user' => 'Aggiungi nuovo utente',
  'Administrator group could not be deleted!' => '',
  'All open registration invitations were successfully deleted.' => '',
  'All the personal data of this user will be irrevocably deleted.' => 'Tutti di dati personali di questo utente verranno irrimediabilmente eliminati.',
  'Allow' => 'Consenti',
  'Allow users to set individual permissions for their own profile?' => '',
  'Allow visitors limited access to content without an account (Adds visibility: "Guest")' => 'Consenti accesso limitato per gli utenti non autenticati (guest)',
  'Applied to new or existing users without any other group membership.' => '',
  'Are you really sure that you want to disable this user?' => 'Sei proprio sicuro di disabilitare questo utente?',
  'Are you really sure that you want to enable this user?' => 'Sei proprio sicuro di abilitare questo utente?',
  'Are you really sure that you want to impersonate this user?' => 'Sei proprio sicuro di impersonare questo utente?',
  'Are you really sure? Users who are not assigned to another group are automatically assigned to the default group.' => '',
  'Are you sure that you want to delete following user?' => 'Sei proprio sicuro di eliminare i seguenti utenti?',
  'Cancel' => 'Annulla',
  'Click here to review' => 'Clicca qui per analizzare',
  'Confirm user deletion' => 'Conferma la cancellazione',
  'Could not load category.' => 'Non posso caricare la categoria.',
  'Create new group' => 'Crea nuovo gruppo',
  'Create new profile category' => 'Crea nuova categoria profilo',
  'Create new profile field' => 'Crea nuovo campo profilo',
  'Deactivate' => '',
  'Deactivate individual profile permissions?' => '',
  'Decline & delete user: <strong>{displayName}</strong>' => 'Rifiuta e cancella l\'utente: <strong>{displayName}</strong>',
  'Default' => 'Predefinito',
  'Default Profile Permissions' => '',
  'Default content of the registration approval email' => 'Contenuto predefinito dell\'email per l\'autorizzazione di registrazione di un utente',
  'Default content of the registration denial email' => 'Contenuto predefinito dell\'email per la mancata autorizzazione di registrazione di un utente',
  'Default groups can not be deleted!' => '',
  'Default user idle timeout, auto-logout (in seconds, optional)' => 'Tempo standard di timeout per inattività, auto disconnessione (in secondi, facoltativo)',
  'Default user profile visibility' => 'Visibilità predefinita per il profilo utente',
  'Delete' => 'Elimina',
  'Delete All' => '',
  'Delete all contributions of this user' => 'Cancella tutti i contenuti dell\'utente',
  'Delete invitation' => 'Cancella invito',
  'Delete invitation?' => 'Annulla l\'invito?',
  'Delete spaces which are owned by this user' => 'Cancella tutti gli spazi posseduti dall\'utente',
  'Deleted invitation' => 'Inviti eliminati',
  'Deleted users' => 'Utenti eliminati',
  'Disable' => 'Disabilita',
  'Disabled' => 'Disabilitato',
  'Disabled users' => 'Utenti disabilitati',
  'Do not change placeholders like {displayName} if you want them to be automatically filled by the system. To reset the email content fields with the system default, leave them empty.' => 'Non modificare segnaposti come {displayName} se vuoi che vengano automaticamente compilati dal sistema. Per ripristinare i campi del contenuto dell\'email con il valore predefinito del sistema, lasciali vuoti.',
  'Edit category' => 'Modifica categoria',
  'Edit profile category' => 'Modifica categoria profilo',
  'Edit profile field' => 'Modifica campo profilo',
  'Edit user: {name}' => 'Modifica utente: {name}',
  'Enable' => 'Abilita',
  'Enable individual profile permissions' => '',
  'Enabled' => 'Abilitato',
  'Group Manager' => 'Manager del guppo',
  'Group not found!' => 'Gruppo non trovato!',
  'Group user not found!' => 'Gruppo utente non trovato!',
  'Groups' => 'Gruppi',
  'Hello {displayName},<br><br>
Your account has been activated.<br><br>
Click here to login:<br>
{loginLink}<br><br>

Kind Regards<br>
{AdminName}<br><br>' => 'Ciao {displayName},<br><br> il tuo account è stato attivato.<br><br> Clicca qui per collegarti:<br> {loginLink}<br><br> Saluti <br> {AdminName}<br><br>',
  'Hello {displayName},<br><br>
Your account request has been declined.<br><br>

Kind Regards<br>
{AdminName} <br><br> ' => 'Ciao {displayName},<br><br> la richiesta di attivazione del tuo account è stata respinta.<br><br> Saluti <br> {AdminName} <br><br>',
  'Here you can create or edit profile categories and fields.' => 'Qui puoi creare o modificare le categorie del profilo e i campi',
  'If individual profile permissions are not allowed, the following settings are unchangeable for all users. If individual profile permissions are allowed, the settings are only set as defaults that users can customise. The following entries are then displayed in the same form in the users profile settings:' => '',
  'If this option is not selected, the ownership of the spaces will be transferred to your account.' => 'Se l\'opzione non è selezionata, la proprietà di questo spazio verrà trasferita al tuo account.',
  'Impersonate' => 'Impersonifica',
  'Include captcha in registration form' => 'Aggiungi Captcha nella scheda di registrazione',
  'Invite not found!' => 'Invito non trovato!',
  'Last login' => 'Ultimo accesso',
  'List pending registrations' => 'Lista delle registrazioni in attesa',
  'Make the group selectable at registration.' => '',
  'Manage group: {groupName}' => 'Gestisci gruppo: {groupName}',
  'Manage groups' => 'Gestisci gruppi',
  'Manage profile attributes' => 'Gestisci gli attributi del profilo',
  'Member since' => 'Membro da',
  'Members' => 'Membri',
  'Members can invite external users by email' => 'I membri possono invitare utenti esterni via email',
  'Message' => 'Messaggio',
  'Min value is 20 seconds. If not set, session will timeout after 1400 seconds (24 minutes) regardless of activity (default session timeout)' => 'Il valore minimo è 20 secondi. Se non impostato, la sessione terminerà dopo 1400 secondi, ovvero 24 minuti di inattività. (default session timeout)',
  'New approval requests' => 'Nuove richieste da approvare',
  'New users can register' => 'Gli utenti anonimi possono registrarsi',
  'No' => 'No',
  'No value found!' => 'Valore non trovato!',
  'One or more user needs your approval as group admin.' => 'Uno o più utenti hanno bisogno della tua approvazione come amministratore del gruppo.',
  'Only applicable when limited access for non-authenticated users is enabled. Only affects new users.' => 'Applicabile solo quando è attivato l\'acceso per gli utenti non registrati. Riguarda solo i nuovi utenti.',
  'Overview' => 'Panoramica',
  'Password' => 'Password',
  'Pending approvals' => 'Approvazioni in sospeso',
  'Pending user approvals' => 'Approvazioni utente in attesa',
  'Permanently delete' => 'Elimina definitivamente',
  'Permissions' => 'Permessi',
  'Profile Permissions' => '',
  'Profiles' => 'Profili',
  'Remove from group' => 'Rimuovi dal gruppo',
  'Require group admin approval after registration' => 'Richiede l\'approvazione dell\'amministratore del gruppo dopo la registrazione',
  'Resend invitation email' => 'Invia di nuovo l\'invito per email',
  'Save' => 'Salva',
  'Search by name, email or id.' => 'Cerca per nome, email o id',
  'Select Groups' => 'Seleziona Gruppi',
  'Send & save' => 'Invia e salva',
  'Send invitation email' => 'Invia invito per email',
  'Send invitation email again?' => 'Invia nuovamente l\'invito per email?',
  'Send invite' => 'Invia invito',
  'Send notifications to users when added to or removed from the group.' => '',
  'Settings' => 'Impostazioni',
  'Show group selection at registration' => '',
  'Subject' => 'Soggetto',
  'The Space memberships of all group members will be updated. This may take up to several minutes.' => '',
  'The following list contains all pending sign-ups and invites.' => 'La seguente lista contiene tutte le richieste di partecipazione ed inviti in sospeso.',
  'The following list contains all registered users awaiting an approval.' => 'La seguente lista contiene tutte le registrazioni degli utenti in attesa di approvazione.',
  'The selected invitations have been successfully deleted!' => '',
  'The user is the owner of these spaces:' => 'L\'utente è proprietario di questi spazi.',
  'This option allows you to determine whether users may set individual permissions for their own profiles.' => '',
  'This overview contains a list of each registered user with actions to view, edit and delete users.' => 'Questo riepilogo contiene la lista di ogni utente registrato, puoi visualizzare, modificare e eliminare gli utenti.',
  'This user owns no spaces.' => 'Questo utente non è proprietario di alcun spazio.',
  'Unapproved' => 'Non approvato',
  'User deletion process queued.' => 'Cancellazione dell\'utente in attesa.',
  'User is already a member of this group.' => 'L\'utente è già menbro di questo gruppo.',
  'User not found!' => 'Utente non trovato!',
  'Users' => 'Utenti',
  'Users can be assigned to different groups (e.g. teams, departments etc.) with specific standard spaces, group managers and permissions.' => 'Gli utenti possono essere assegnati a gruppi differenti gruppi con degli spazi predefiniti, gruppi, manager e permessi.',
  'Using this option any contributions (e.g. contents, comments or likes) of this user will be irrevocably deleted.' => 'Con questa opzione ogni contenuto di questo utente verrà permanentemente eliminato. (post, commenti, like)',
  'View profile' => 'Visualizza profilo',
  'Visible for members only' => 'Visibile solo per i membri',
  'Visible for members+guests' => 'Visibile per i membri e gli ospiti',
  'Yes' => 'Sì',
  'You can only delete empty categories!' => 'Puoi cancellare solo categorie vuote!',
  'You cannot delete yourself!' => 'Non puoi eliminare te stesso!',
  'never' => 'mai',
);

==> humhub-1.10.2.tar.gz: humhub-1.10.2/protected/humhub/modules/admin/messages/it/user.php <==
<?php
return array (
  '<strong>Information</strong>' => '<strong>Informazioni</strong>',
  '<strong>Profile</strong> Permissions' => 'Autorizzazioni <strong>Profilo</strong>',
  '<strong>Settings</strong> and Configuration' => '<strong>Impostazioni</strong> e Configurazione',
  '<strong>User</strong> administration' => 'Amministrazione <strong>Utente</strong>',
  '<strong>Warning:</strong> All individual profile permission settings are reset to the default values!' => '<strong>Attenzione:</strong> tutte le impostazioni di autorizzazione del profilo individuale vengono ripristinate ai valori predefiniti!',
  'Accept user: <strong>{displayName}</strong> ' => 'Accetta utente: <strong>{displayName}</strong>',
  'Account' => 'Account',
  'Account Request for \'{displayName}\' has been approved.' => 'La richiesta account per \'{displayName}\'  è stata approvata',
  'Account Request for \'{displayName}\' has been declined.' => 'La richiesta account per \'{displayName}\'  è stata rifiutata',
  'Actions' => 'Azioni',
  'Active users' => 'Utenti attivi',
  'Add Groups...' => 'Aggiungi Gruppi...',
  'Add new category' => 'Aggiungi nuova categoria',
  'Add new field' => 'Aggiungi nuovo campo',
  'Add new group' => 'Aggiungi nuovo gruppo',
  'Add new members...' => 'Aggiungi nuovi membri...',
  'Add new user' => 'Aggiungi nuovo utente',
  'Administrator group could not be deleted!' => 'Impossibile eliminare il gruppo di amministratori!',
  'All open registration invitations were successfully deleted.' => 'Tutti gli inviti di registrazione aperti sono stati eliminati con successo.',
  'All the personal data of this user will be irrevocably deleted.' => 'Tutti di dati personali di questo utente verranno irrimediabilmente eliminati.',
  'Allow' => 'Consenti',
  'Allow users to block each other' => '',
  'Allow users to set individual permissions for their own profile?' => 'Consentire agli utenti di impostare autorizzazioni individuali per il proprio profilo?',
  'Allow visitors limited access to content without an account (Adds visibility: "Guest")' => 'Consenti accesso limitato per gli utenti non autenticati (guest)',
  'Applied to new or existing users without any other group membership.' => 'Applicato a utenti nuovi o esistenti senza altri membri del gruppo.',
  'Are you really sure that you want to disable this user?' => 'Sei proprio sicuro di disabilitare questo utente?',
  'Are you really sure that you want to enable this user?' => 'Sei proprio sicuro di abilitare questo utente?',
  'Are you really sure that you want to impersonate this user?' => 'Sei proprio sicuro di impersonare questo utente?',
  'Are you really sure? Users who are not assigned to another group are automatically assigned to the default group.' => 'Sei proprio sicuro? Gli utenti che non sono assegnati a un altro gruppo vengono assegnati automaticamente al gruppo predefinito.',
  'Are you sure that you want to delete following user?' => 'Sei proprio sicuro di eliminare i seguenti utenti?',
  'Cancel' => 'Annulla',
  'Click here to review' => 'Clicca qui per analizzare',
  'Confirm user deletion' => 'Conferma la cancellazione',
  'Could not load category.' => 'Non posso caricare la categoria.',
  'Create new group' => 'Crea nuovo gruppo',
  'Create new profile category' => 'Crea nuova categoria profilo',
  'Create new profile field' => 'Crea nuovo campo profilo',
  'Deactivate' => 'Disattivare',
  'Deactivate individual profile permissions?' => 'Disattivare le autorizzazioni del profilo individuale?',
  'Decline & delete user: <strong>{displayName}</strong>' => 'Rifiuta e cancella l\'utente: <strong>{displayName}</strong>',
  'Default' => 'Predefinito',
  'Default Profile Permissions' => 'Autorizzazioni profilo predefinite',
  'Default Sorting' => 'Ordinamento predefinito',
  'Default content of the registration approval email' => 'Contenuto predefinito dell\'email per l\'autorizzazione di registrazione di un utente',
  'Default content of the registration denial email' => 'Contenuto predefinito dell\'email per la mancata autorizzazione di registrazione di un utente',
  'Default group can not be deleted!' => '',
  'Default user idle timeout, auto-logout (in seconds, optional)' => 'Tempo standard di timeout per inattività, auto disconnessione (in secondi, facoltativo)',
  'Default user profile visibility' => 'Visibilità predefinita per il profilo utente',
  'Delete' => 'Elimina',
  'Delete All' => 'Cancella tutto',
  'Delete all contributions of this user' => 'Cancella tutti i contenuti dell\'utente',
  'Delete invitation' => 'Cancella invito',
  'Delete invitation?' => 'Annulla l\'invito?',
  'Delete spaces which are owned by this user' => 'Cancella tutti gli spazi posseduti dall\'utente',
  'Deleted invitation' => 'Inviti eliminati',
  'Deleted users' => 'Utenti eliminati',
  'Disable' => 'Disabilita',
  'Disabled' => 'Disabilitato',
  'Disabled users' => 'Utenti disabilitati',
  'Do not change placeholders like {displayName} if you want them to be automatically filled by the system. To reset the email content fields with the system default, leave them empty.' => 'Non modificare segnaposti come {displayName} se vuoi che vengano automaticamente compilati dal sistema. Per ripristinare i campi del contenuto dell\'email con il valore predefinito del sistema, lasciali vuoti.',
  'Edit category' => 'Modifica categoria',
  'Edit profile category' => 'Modifica categoria profilo',
  'Edit profile field' => 'Modifica campo profilo',
  'Edit user: {name}' => 'Modifica utente: {name}',
  'Enable' => 'Abilita',
  'Enable individual profile permissions' => 'Abilita i permessi del profilo individuale',
  'Enabled' => 'Abilitato',
  'First name' => 'Nome',
  'Group Manager' => 'Manager del guppo',
  'Group not found!' => 'Gruppo non trovato!',
  'Group user not found!' => 'Gruppo utente non trovato!',
  'Groups' => 'Gruppi',
  'Hello {displayName},

Your account has been activated.

Click here to login:
{loginUrl}

Kind Regards
{AdminName}

' => '',
  'Hello {displayName},

Your account request has been declined.

Kind Regards
{AdminName}

' => '',
  'Here you can create or edit profile categories and fields.' => 'Qui puoi creare o modificare le categorie del profilo e i campi',
  'If individual profile permissions are not allowed, the following settings are unchangeable for all users. If individual profile permissions are allowed, the settings are only set as defaults that users can customise. The following entries are then displayed in the same form in the users profile settings:' => 'Se le autorizzazioni del profilo individuale non sono consentite, le seguenti impostazioni non sono modificabili per tutti gli utenti. Se sono consentiti i permessi del profilo individuale, le impostazioni vengono impostate solo come predefinite che gli utenti possono personalizzare. Le seguenti voci vengono quindi visualizzate nello stesso modulo nelle impostazioni del profilo utente:',
  'If this option is not selected, the ownership of the spaces will be transferred to your account.' => 'Se l\'opzione non è selezionata, la proprietà di questo spazio verrà trasferita al tuo account.',
  'Impersonate' => 'Impersonifica',
  'Include captcha in registration form' => 'Aggiungi Captcha nella scheda di registrazione',
  'Information 1' => 'Informazioni 1',
  'Information 2' => 'Informazioni 2',
  'Information 3' => 'Informazioni 3',
  'Invite not found!' => 'Invito non trovato!',
  'Last login' => 'Ultimo accesso',
  'Last name' => 'Cognome',
  'List pending registrations' => 'Lista delle registrazioni in attesa',
  'Make the group selectable at registration.' => 'Rendi il gruppo selezionabile al momento della registrazione.',
  'Manage group: {groupName}' => 'Gestisci gruppo: {groupName}',
  'Manage groups' => 'Gestisci gruppi',
  'Manage profile attributes' => 'Gestisci gli attributi del profilo',
  'Member since' => 'Membro da',
  'Members' => 'Membri',
  'Members can invite external users by email' => 'I membri possono invitare utenti esterni via email',
  'Message' => 'Messaggio',
  'Min value is 20 seconds. If not set, session will timeout after 1400 seconds (24 minutes) regardless of activity (default session timeout)' => 'Il valore minimo è 20 secondi. Se non impostato, la sessione terminerà dopo 1400 secondi, ovvero 24 minuti di inattività. (default session timeout)',
  'New approval requests' => 'Nuove richieste da approvare',
  'New users can register' => 'Gli utenti anonimi possono registrarsi',
  'No' => 'No',
  'No value found!' => 'Valore non trovato!',
  'None' => 'Nessuno',
  'Not visible' => 'Invisibile',
  'One or more user needs your approval as group admin.' => 'Uno o più utenti hanno bisogno della tua approvazione come amministratore del gruppo.',
  'Only applicable when limited access for non-authenticated users is enabled. Only affects new users.' => 'Applicabile solo quando è attivato l\'acceso per gli utenti non registrati. Riguarda solo i nuovi utenti.',
  'Overview' => 'Panoramica',
  'Password' => 'Password',
  'Pending approvals' => 'Approvazioni in sospeso',
  'Pending user approvals' => 'Approvazioni utente in attesa',
  'People' => 'Persone',
  'Permanently delete' => 'Elimina definitivamente',
  'Permissions' => 'Permessi',
  'Prioritised User Group' => 'Gruppo utenti prioritari',
  'Profile Permissions' => 'Permessi del profilo',
  'Profiles' => 'Profili',
  'Protected' => 'Protetto',
  'Protected group can not be deleted!' => '',
  'Remove from group' => 'Rimuovi dal gruppo',
  'Require group admin approval after registration' => 'Richiede l\'approvazione dell\'amministratore del gruppo dopo la registrazione',
  'Resend invitation email' => 'Invia di nuovo l\'invito per email',
  'Save' => 'Salva',
  'Search by name, email or id.' => 'Cerca per nome, email o id',
  'Select Groups' => 'Seleziona Gruppi',
  'Select a prioritised group whose members are displayed before all others when the sorting option \'Default\' is selected. The users within the group and the users outside the group are additionally sorted by their last login.' => 'Seleziona un gruppo prioritario i cui membri vengono visualizzati prima di tutti gli altri quando è selezionata l\'opzione di ordinamento "Predefinito". Gli utenti all\'interno del gruppo e gli utenti al di fuori del gruppo vengono inoltre ordinati in base all\'ultimo accesso.',
  'Select which user information should be displayed in the \'People\' overview. You can select any profile fields, even those you have created individually. ' => 'Seleziona quali informazioni utente devono essere visualizzate nella panoramica "Persone". Puoi selezionare qualsiasi campo del profilo, anche quelli che hai creato individualmente.',
  'Send & decline' => 'Invia e rifiuta',
  'Send & save' => 'Invia e salva',
  'Send invitation email' => 'Invia invito per email',
  'Send invitation email again?' => 'Invia nuovamente l\'invito per email?',
  'Send invite' => 'Invia invito',
  'Send notifications to users when added to or removed from the group.' => 'Invia notifiche agli utenti quando vengono aggiunti o rimossi dal gruppo.',
  'Settings' => 'Impostazioni',
  'Show group selection at registration' => 'Mostra la selezione del gruppo al momento della registrazione',
  'Subject' => 'Soggetto',
  'The Space memberships of all group members will be updated. This may take up to several minutes.' => 'Le iscrizioni allo spazio di tutti i membri del gruppo verranno aggiornate. Questa operazione potrebbe richiedere diversi minuti.',
  'The following list contains all pending sign-ups and invites.' => 'La seguente lista contiene tutte le richieste di partecipazione ed inviti in sospeso.',
  'The following list contains all registered users awaiting an approval.' => 'La seguente lista contiene tutte le registrazioni degli utenti in attesa di approvazione.',
  'The selected invitations have been successfully deleted!' => 'Gli inviti selezionati sono stati eliminati con successo!',
  'The user is the owner of these spaces:' => 'L\'utente è proprietario di questi spazi.',
  'This option allows you to determine whether users may set individual permissions for their own profiles.' => 'Questa opzione consente di determinare se gli utenti possono impostare autorizzazioni individuali per i propri profili.',
  'This overview contains a list of each registered user with actions to view, edit and delete users.' => 'Questo riepilogo contiene la lista di ogni utente registrato, puoi visualizzare, modificare e eliminare gli utenti.',
  'This user owns no spaces.' => 'Questo utente non è proprietario di alcun spazio.',
  'Unapproved' => 'Non approvato',
  'User deletion process queued.' => 'Cancellazione dell\'utente in attesa.',
  'User is already a member of this group.' => 'L\'utente è già menbro di questo gruppo.',
  'User not found!' => 'Utente non trovato!',
  'Users can be assigned to different groups (e.g. teams, departments etc.) with specific standard spaces, group managers and permissions.' => 'Gli utenti possono essere assegnati a gruppi differenti gruppi con degli spazi predefiniti, gruppi, manager e permessi.',
  'Using this option any contributions (e.g. contents, comments or likes) of this user will be irrevocably deleted.' => 'Con questa opzione ogni contenuto di questo utente verrà permanentemente eliminato. (post, commenti, like)',
  'View profile' => 'Visualizza profilo',
  'Visible for members only' => 'Visibile solo per i membri',
  'Visible for members+guests' => 'Visibile per i membri e gli ospiti',
  'Will be used as a filter in \'People\'.' => 'Verrà utilizzato come filtro in "Persone".',
  'Yes' => 'Sì',
  'You can only delete empty categories!' => 'Puoi cancellare solo categorie vuote!',
  'You cannot delete yourself!' => 'Non puoi eliminare te stesso!',
  'never' => 'mai',
);
